/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/ 
 * 
 *  SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.validation.rules.portsandflows;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.validation.AbstractModelConstraint;
import org.eclipse.emf.validation.IValidationContext;
import org.eclipse.papyrus.sysml14.portsandflows.InterfaceBlock;
import org.eclipse.uml2.uml.Behavior;
import org.eclipse.uml2.uml.Class;

/**
 * 
 * 9.3.2.9 InterfaceBlock [1] Interface blocks cannot own or inherit behaviors,
 * have classifier behaviors, or methods for their behavioral features
 *
 */
public class InterfaceBlockNoBehaviorConstraint extends AbstractModelConstraint {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.emf.validation.AbstractModelConstraint#validate(org.eclipse.
	 * emf.validation.IValidationContext)
	 */
	@Override
	public IStatus validate(IValidationContext context) {
		InterfaceBlock interfaceBlock = (InterfaceBlock) context.getTarget();
		Class clazz = interfaceBlock.getBase_Class();
		if (clazz != null) {
			if (clazz.getClassifierBehavior() != null) {
				return context.createFailureStatus(context.getTarget());
			}
			EList<Behavior> ownedBehaviors = clazz.getOwnedBehaviors();
			if (ownedBehaviors != null && !ownedBehaviors.isEmpty()) {
				return context.createFailureStatus(context.getTarget());
			}
		}
		return context.createSuccessStatus();
	}
}
